@@ -938,8 +938,8 @@ class FineTransformer(nn.Module):
         coarse_pos = repeat(coarse_pos, 'n -> (n q)', q = self.num_coarse_quantizers)[:coarse_length]
         fine_pos = repeat(fine_pos, 'n -> (n q)', q = self.num_fine_quantizers)[:fine_length]
 
-        coarse_pos = F.pad(coarse_pos, (1, 0), value = 0)
-        fine_pos = F.pad(fine_pos, (1, 0), value = 0)
+        coarse_pos = F.pad(coarse_pos, (1, 0), value = -1)
+        fine_pos = F.pad(fine_pos, (1, 0), value = -1)
 
         seq_positions = torch.cat((coarse_pos, fine_pos), dim = -1)
 
@@ -949,7 +949,7 @@ class FineTransformer(nn.Module):
 
         seq_offsets = torch.cat((coarse_offsets, fine_offsets), dim = -1)
 
-        pos_mlp_input = torch.stack((seq_positions, seq_offsets), dim = -1)
+        pos_mlp_input = torch.stack((seq_positions.clamp(min = 0), seq_offsets), dim = -1)
 
         num_offsets = self.num_fine_quantizers + self.num_coarse_quantizers
 
